# Web3.py on OSX

## Developer Setup

1. Install XCode command line tools

```sh
xcode-select --install
```

2. Install all of the package dependencies

```sh
brew install openssl libffi autoconf automake libtool
```

3. Install `leveldb`

```sh
brew install leveldb
```
